# XGEE Core

The core components of the XGEE JavaScript frontend implementation.

# XGEE
XGEE stands for eXtensible Graphical EMOF Editor. XGEE is a web framework for the creation of web-based graphical editors for domain-specific models.

XGEE allows domain-specific modeling directly in your browser. You can use it locally, host it on your own, or you give it a try with the online demonstrator. Even mobile modeling on your smartphone is possible.

Project website: https://www.xgee.de/

Main repository: https://gitlab.com/xgee/xgee-core

Documentation: https://docs.xgee.de/
